@@ -1,9 +1,11 @@
-import requests
+import zipfile
 from getpass import getpass
 
+import requests
+
 from quera.utils.cache import cache
 
-JUDGE_API = 'https://quera.org/judge_api/apikey-judge/'
+JUDGE_API = 'https://mirror.quera.org/judge_api/apikey-judge/'
 
 
 def get_apikey() -> str:
@@ -48,3 +50,14 @@ def submit(*, submitting_file_name: str = 'result.zip', api: str = JUDGE_API):
             print(f'Error - {response.status_code}: ', response.content.decode())
         else:
             print('Submitted to Quera Successfully')
+
+
+def submit_files(file_names: list = None):
+    if not file_names:
+        raise Exception('No files selected to submit')
+
+    with zipfile.ZipFile("result.zip", mode="w") as zf:
+        for file_name in file_names:
+            zf.write('./' + file_name, file_name, compress_type=zipfile.ZIP_DEFLATED)
+
+    submit(submitting_file_name="result.zip")
